<?xml version="1.0" encoding="UTF-8"?>
<gui name="kbounce"
     version="6"
     xmlns="http://www.kde.org/standards/kxmlgui/1.0"
     xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
     xsi:schemaLocation="http://www.kde.org/standards/kxmlgui/1.0
                         http://www.kde.org/standards/kxmlgui/1.0/kxmlgui.xsd">

<MenuBar>
    <Menu name="settings">
        <Action name="background_select"/>
        <Action name="background_show"/>
        <Action name="toggle_sound" append="save_merge"/>
    </Menu>
</MenuBar>

<ToolBar name="mainToolBar" noMerge="1"><text>Main Toolbar</text>
    <Action name="game_new"/>
    <Action name="game_pause"/>
</ToolBar>

</gui>
